==> monodevelop_0.9.orig.tar.gz: monodevelop-0.9/Core/src/MonoDevelop.Components/MonoDevelop.Components.Commands/LocalCommandEntry.cs <==
//
// LocalCommandEntry.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

namespace MonoDevelop.Components.Commands
{
	public class LocalCommandEntry: CommandEntry
	{
		Command cmd;
		
		public LocalCommandEntry (Command cmd): base (cmd.Id)
		{
			this.cmd = cmd;
		}
		
		public LocalCommandEntry (object id, string text): base (id)
		{
			cmd = new ActionCommand ();
			cmd.Id = id;
			cmd.Text = text;
		}
		
		internal protected override Gtk.MenuItem CreateMenuItem (CommandManager manager)
		{
			if (manager.FindCommand (CommandId) == null)
				manager.RegisterCommand (cmd, "");

			return base.CreateMenuItem (manager);
		}
		
		internal protected override Gtk.ToolItem CreateToolItem (CommandManager manager)
		{
			if (manager.FindCommand (CommandId) == null)
				manager.RegisterCommand (cmd, "");

			return base.CreateToolItem (manager);
		}
	}
}

==> monodevelop_0.14+dfsg.orig.tar.gz: monodevelop-0.14/Core/src/MonoDevelop.Components/MonoDevelop.Components.Commands/LocalCommandEntry.cs <==
//
// LocalCommandEntry.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

namespace MonoDevelop.Components.Commands
{
	public class LocalCommandEntry: CommandEntry
	{
		Command cmd;
		
		public LocalCommandEntry (Command cmd): base (cmd.Id)
		{
			this.cmd = cmd;
		}
		
		public LocalCommandEntry (object id, string text): base (id)
		{
			cmd = new ActionCommand ();
			cmd.Id = id;
			cmd.Text = text;
		}
		
		internal protected override Gtk.MenuItem CreateMenuItem (CommandManager manager)
		{
			if (manager.GetCommand (CommandId) == null)
				manager.RegisterCommand (cmd, "");

			return base.CreateMenuItem (manager);
		}
		
		internal protected override Gtk.ToolItem CreateToolItem (CommandManager manager)
		{
			if (manager.GetCommand (CommandId) == null)
				manager.RegisterCommand (cmd, "");

			return base.CreateToolItem (manager);
		}
	}
}
